-- Globals:
-- ========

SimpleGold_variablesLoaded = false;
SimpleGold_firstRun = true;
SimpleGold_UpdateInterval = 5; -- shouldn't need to update often.
SimpleGold_UpdateTimer = 0;

-- Globals

-- Locals:
-- =======



local myPlayerRealm=GetRealmName();
local myPlayerName=UnitName("player");
local myPlayerID=myPlayerName.."**"..myPlayerRealm;
local myPlayerClassText, myPlayerClassType = UnitClass("player");

local lastWindowState = false;

-- preset color options:
local colorPresetList ={
{1,1,1,0}, 
{0,0,0,1},
{0,0,0,.6},
{.5,.5,.5,.6},

{.5,0,0,.6},
{.5,0,0,1},
{1,0,0,1},

{0,.5,0,.6},
{0,.5,0,1},
{0,1,0,1},

{0,0,.5,.6},
{.5,0,.5,1},
{0,0,1,1},

{.5,.5,0,.6},
{.5,.5,0,1},
{1,1,0,1},

{.5,0,.5,.6},
{.5,0,.5,1},
{1,0,1,1},

{0,.5,.5,.6},
{0,.5,.5,1},
{0,1,1,1}

}


-- My local functions:
-- ====================

function DrawBG()
-------- ---------------
		FixVars();
		local tColor=SimpleGoldSavedVars["color"];
		SimpleGold_BackgroundTexture:SetVertexColor(tColor[1],tColor[2],tColor[3],tColor[4]);
end


function UpdateGlobalGold()
-------- ---------------
	if (SimpleGoldGlobals == nil) then
		SimpleGoldGlobals = {};
	end
	if (SimpleGoldGlobals[myPlayerRealm]==nil) then
		SimpleGoldGlobals[myPlayerRealm]={};
	end
	SimpleGoldGlobals[myPlayerRealm][myPlayerName]=GetMoney();
end


function FixVars()
-------- ---------------
-- initialize our saved variables if needed
	if (SimpleGoldSavedVars == nil) then		
		SimpleGoldSavedVars={
			xPos=0,
			yPos=0,
			lastPreset=1,
			color={0,0,0,1},
			borderStyle=1,
			viz=true,
			locked=false
	};
	end
	if SimpleGoldSavedVars["viz"] == nil then
		SimpleGoldSavedVars["viz"]=true;
	end
	if SimpleGoldSavedVars["locked"] == nil then
		SimpleGoldSavedVars["locked"]=false;
	end
end



function SimpleGold_OnLoad(self)
	-- Register the slash command
	-- --------------------------
	SLASH_SimpleGold1 = "/simplegold";
	SlashCmdList["SimpleGold"] = SimpleGold_CommandLine;


-- Register the event handlers:
-- =============================	

	self:RegisterEvent("VARIABLES_LOADED");
	self:RegisterEvent("PLAYER_MONEY");
	self:RegisterEvent("PLAYER_ENTERING_WORLD");	
	-- new event: CURRENCY_DISPLAY_UPDATE ?
	if (not myPlayerName) then
		myPlayerName = UnitName("player");
		myPlayerID=myPlayerName.."**"..myPlayerRealm;
	end

	DEFAULT_CHAT_FRAME:AddMessage(SGOLDTEXT.WELCOME,  0.5, 1.0, 0.5, 1);
	UpdateGlobalGold();

end -- OnLoad




	
function SimpleGold_Event(self, event, ...)
	local eventHandled = false;

	-- VARIABLES_LOADED
	-- ================
	if ( event == "VARIABLES_LOADED" ) then	
		-- record that we have been loaded:
		SimpleGold_variablesLoaded = true;
		FixVars();
		lastWindowState= not(SimpleGoldSavedVars["viz"]); -- guarantee initial draw
		eventHandled = true;
	end -- ( event == "VARIABLES_LOADED" )
	
	
	-- Money events:	
	if (eventHandled == false and event == "PLAYER_MONEY") then
		SimpleGoldUpdate(self);
		eventHandled = true;
	end 

	if (eventHandled == false and event == "PLAYER_ENTERING_WORLD") then
		SimpleGoldUpdate(self); -- show the frame if necessary
		eventHandled = true;
	end 
end -- SimpleGold_Event
 


-- command line parameters: (slash command handler)
function SimpleGold_CommandLine(msg)
	local tName;
	local normalizedName;
	local normalizedIndex;
	local foundIndex = nil;
	local oStr, toss;
	
	cmd=string.lower(msg);

	-- display the help mesage:
	if ( msg=="" or cmd=="help") then
		local p="/simplegold ";
		DEFAULT_CHAT_FRAME:AddMessage(SASSTEXT_TITLE,  0.5, 1.0, 0.5, 1);
		DEFAULT_CHAT_FRAME:AddMessage(SGOLDTEXT.HELP,  0.8, 0.8, 0.8, 1);
		DEFAULT_CHAT_FRAME:AddMessage(p..SGOLDTEXT.SHOW .. " - " .. SGOLDTEXT.SHOW_DESCRIPTION,  0.8, 0.8, 0.8, 1);
		DEFAULT_CHAT_FRAME:AddMessage(p..SGOLDTEXT.HIDE .. " - " .. SGOLDTEXT.HIDE_DESCRIPTION,  0.8, 0.8, 0.8, 1);
		DEFAULT_CHAT_FRAME:AddMessage(p..SGOLDTEXT.LOCK .. " - " .. SGOLDTEXT.LOCK_DESCRIPTION,  0.8, 0.8, 0.8, 1);
		DEFAULT_CHAT_FRAME:AddMessage(p..SGOLDTEXT.UNLOCK .. " - " .. SGOLDTEXT.UNLOCK_DESCRIPTION,  0.8, 0.8, 0.8, 1);
		DEFAULT_CHAT_FRAME:AddMessage(p..SGOLDTEXT.DELETE .. " {character name} - " .. SGOLDTEXT.DELETE_DESCRIPTION,  0.8, 0.8, 0.8, 1);
	end

	local delStart, delEnd = string.find(cmd,"delete ",1);
	if (delStart) then
		tName=(string.sub(msg,delEnd+1));
		-- CONFIRM_DELETE="Character &CHARNAME removed from list."
		local tList=SimpleGoldGlobals[myPlayerRealm];
		normalizedName=SimpleGold_NormalizeString(tName);
		if (strlenutf8(normalizedName)>0) then
		
		
			-- look for the name in this realm:
			for k, v in pairs (tList) do
				normalizedIndex=SimpleGold_NormalizeString(k);
				if (normalizedIndex == normalizedName) then
					foundIndex=k
				end
			end -- loop through the names

	
			if (foundIndex ~= nil) then
				SimpleGoldGlobals[myPlayerRealm][foundIndex]=nil;	
				oStr, toss= string.gsub(SGOLDTEXT.CONFIRM_DELETE, "_CHARNAME_", tName);
			else
				oStr, toss= string.gsub(SGOLDTEXT.NOTOON, "_CHARNAME_", tName);
			end
			
			DEFAULT_CHAT_FRAME:AddMessage(oStr,  0.8, 0.8, 0.8, 1);
			
		end -- able to parse a name

	end

	if ( cmd == SGOLDTEXT.SHOW) then
		SimpleGoldDisplayFrame:Show();
		DEFAULT_CHAT_FRAME:AddMessage(SGOLDTEXT.CONFIRM_SHOWING,  0.8, 0.8, 0.8, 1);
	end
		
	if ( cmd == SGOLDTEXT.HIDE) then
		SimpleGoldDisplayFrame:Hide();
		SimpleGoldSavedVars["viz"]=false;
		DEFAULT_CHAT_FRAME:AddMessage(SGOLDTEXT.CONFIRM_HIDING,  0.8, 0.8, 0.8, 1);
	end
	
	if ( cmd == SGOLDTEXT.LOCK) then
		SimpleGoldSavedVars["locked"]=true;
		DEFAULT_CHAT_FRAME:AddMessage(SGOLDTEXT.CONFIRM_LOCKED,  0.8, 0.8, 0.8, 1);
	end
	
	if ( cmd == SGOLDTEXT.UNLOCK) then
		SimpleGoldSavedVars["locked"]=false;
		DEFAULT_CHAT_FRAME:AddMessage(SGOLDTEXT.CONFIRM_UNLOCKED,  0.8, 0.8, 0.8, 1);

	end
	
end


function SimpleGoldUpdate(self)
	if (lastWindowState == SimpleGoldSavedVars["viz"]) then
		-- we don't really need to update do we?
	else
		lastWindowState = SimpleGoldSavedVars["viz"];
		if (lastWindowState) then
			SimpleGoldDisplayFrame:Show();
		else
			SimpleGoldDisplayFrame:Hide();
		end
	end
	local money = GetMoney();
	UpdateGlobalGold();
	MoneyFrame_Update("SimpleGoldMoney", money); --"SimpleGoldMoney", money
	DrawBG();

end

function SimpleGoldServiceUpdate(elapsed)
	 
	SimpleGold_UpdateTimer = SimpleGold_UpdateTimer + elapsed; 	
	if (SimpleGold_UpdateTimer > SimpleGold_UpdateInterval) then
	-- DEFAULT_CHAT_FRAME:AddMessage("tick",  0.5, 1.0, 0.5, 1);
		SimpleGoldUpdate();
		SimpleGold_UpdateTimer = 0;
	end

end

-- GUI Handlers:
-- =============================


-- prefs:
-- function SimpleGold_Options_OnClick(arg1)
-- 	id = this:GetID()
-- 	local buttonName=this:GetName()
-- 	SimpleGoldDefaults[buttonName] =getglobal(buttonName):GetChecked();
-- 	SimpleGoldSavedVars[buttonName] =getglobal(buttonName):GetChecked();
-- end




 -- OnShow
function SimpleGoldPrefsFrameOnShow()

	DrawBG();
	SimpleGoldSavedVars["viz"]=true;
	-- SimpleGoldUpdate();
	
end


function SimpleGoldPrefsFrameOnHide()
	SimpleGoldSavedVars["viz"]=false;
end


function SimpleGold_StepBackground()
	FixVars();
	
	local currentStep=SimpleGoldSavedVars["lastPreset"];
	local presetCount=#(colorPresetList);
	currentStep=currentStep+1;
	if (currentStep > presetCount) then
		currentStep=1;
	end
	local tColor=colorPresetList[currentStep];
	SimpleGold_BackgroundTexture:SetVertexColor(tColor[1],tColor[2],tColor[3],tColor[4]);
	SimpleGoldSavedVars["lastPreset"]=currentStep;
	SimpleGoldSavedVars["color"]=tColor;
	-- SimpleGold_BackgroundTexture:SetTexture(1,1,1,0);
	
	-- Frame:SetBackdrop([backdropTable]) - Set the backdrop of the frame according to the specification provided. 
	-- Frame:SetBackdropBorderColor(r,g,b[,a]) - Set the frame's backdrop's border's color. 
	-- Frame:SetBackdropColor(r,g,b[,a]) - Set the frame's backdrop color.
 end
 




  




function SimpleGold_ShowTooltip()
	local tooltipList ={};
	local totalGold=0;
	-- GameTooltip_SetDefaultAnchor(GameTooltip, SimpleGoldDisplayFrame);
	GameTooltip:SetOwner(getglobal("SimpleGoldDisplayFrame") , "ANCHOR_CURSOR", -5, 5);
	-- GameTooltip:SetOwner(owner, "anchor"[, +x, +y]);
	--GameTooltip:AddLine("test", .6,1.0,.8); -- GameTooltip:AddLine(name, GameTooltip_UnitColor("player"));\
	-- add up the gold for this realm:
	if (SimpleGoldGlobals==nil) then
		table.insert(tooltipList,"Gold Data Unavailable");
	else
		local thisRealmList=SimpleGoldGlobals[myPlayerRealm];
		for k,v in pairs(thisRealmList) do
			-- table.insert(tooltipList,k..'    '..string.format("%.4f",v/10000));
			table.insert(tooltipList,{k,string.format("%.2f",v/10000)});
			totalGold=totalGold+v;
		end --thisRealmList
		
	end
	if (#(tooltipList))>0 then
		GameTooltip:AddLine("Total:   "..string.format("%.2f",totalGold/10000), .8, .8, 1.8);
		for i = 1, #(tooltipList) do
			-- GameTooltip:AddLine(tooltipList[i], .8, .8, 1.8);
			GameTooltip:AddLine(tooltipList[i][1]..':   '..tooltipList[i][2], .8, .8, 1.8);
		end -- for fieldCount
	end
	GameTooltip:Show();
end

function SimpleGold_HideTooltip()
	GameTooltip:Hide();
end
  

function SimpleGold_NormalizeString(s)
	-- makes a string lower case and trims whitespace
	s=string.lower(s)
	return (string.gsub(s, "^%s*(.-)%s*$", "%1"))
end

  